==> idp-plugin-duo-api-0.9.1-sources.jar: net/shibboleth/idp/plugin/authn/duo/DuoOIDCClientFactory.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.idp.plugin.authn.duo;

import javax.annotation.Nonnull;

/**
 * Abstract factory for creating {@link DuoOIDCClient} instances.
 */
public interface DuoOIDCClientFactory {
    
    /**
     * Create an {@link DuoOIDCClient} instance from the supplied integration.
     * 
     * @param integration the duo integration used to instantiate the client.
     * 
     * @return the created Duo client, never {@code null}.
     *
     * @throws DuoClientException if there is an error creating the Duo client.
     */
    @Nonnull DuoOIDCClient createInstance(@Nonnull final DuoOIDCIntegration integration) 
            throws DuoClientException; 

}

==> idp-plugin-duo-api-1.3.0-sources.jar: net/shibboleth/idp/plugin/authn/duo/DuoOIDCClientFactory.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.idp.plugin.authn.duo;

import javax.annotation.Nonnull;

/**
 * Abstract factory for creating singleton {@link DuoOIDCClient} instances.
 */
public interface DuoOIDCClientFactory {
    
    /**
     * Create an {@link DuoOIDCClient} instance from the supplied integration.
     * 
     * <p>The client should be fully initialised and safely published.</p>
     * 
     * @param integration the duo integration used to instantiate the client.
     * 
     * @return the created Duo client, never {@code null}.
     *
     * @throws DuoClientException if there is an error creating the Duo client.
     */
    @Nonnull DuoOIDCClient createInstance(@Nonnull final DuoOIDCIntegration integration) 
            throws DuoClientException; 

}
